@@ -16,7 +16,7 @@ class PlanAPI():
         self._fp = flightplandb
 
     def fetch(self, id_: int,
-              return_format: str = "dict") -> Union[Plan, None, bytes]:
+              return_format: str = "native") -> Union[Plan, None, bytes]:
         # Underscore for id_ must be escaped as id\_ so sphinx shows the _.
         # However, this would raise W605. To fix this, a raw string is used.
         r"""
@@ -28,15 +28,16 @@ class PlanAPI():
         id\_ : int
             The ID of the flight plan to fetch
         return_format : str
-            The API response format, defaults to ``"dict"``
+            The API response format, defaults to ``"native"``.
+            Must be one of the keys in the table at the top of the page.
 
         Returns
         -------
         Union[Plan, None, bytes]
-            :class:`~flightplandb.datatypes.Plan` by default or if ``"dict"``
+            :class:`~flightplandb.datatypes.Plan` by default or if ``"native"``
             is specified as the ``return_format``.
 
-            ``bytes`` if a different format than ``"dict"`` was specified.
+            ``bytes`` if a different format than ``"native"`` was specified.
 
         Raises
         ------
@@ -49,13 +50,13 @@ class PlanAPI():
             return_format=return_format
         )
 
-        if return_format == "dict":
+        if return_format == "native":
             return Plan(**request)
 
         return request  # if the format is not a dict
 
     def create(self, plan: Plan,
-               return_format: str = "dict") -> Union[Plan, bytes]:
+               return_format: str = "native") -> Union[Plan, bytes]:
         """Creates a new flight plan.
 
         Requires authentication.
@@ -65,15 +66,16 @@ class PlanAPI():
         plan : Plan
             The Plan object to register on the website
         return_format : str
-            The API response format, defaults to ``"dict"``
+            The API response format, defaults to ``"native"``.
+            Must be one of the keys in the table at the top of the page.
 
         Returns
         -------
         Union[Plan, bytes]
-            :class:`~flightplandb.datatypes.Plan` by default or if ``"dict"``
+            :class:`~flightplandb.datatypes.Plan` by default or if ``"native"``
             is specified as the ``return_format``.
 
-            ``bytes`` if a different format than ``"dict"`` was specified.
+            ``bytes`` if a different format than ``"native"`` was specified.
 
         Raises
         ------
@@ -85,13 +87,13 @@ class PlanAPI():
         request = self._fp._post(
             "/plan/", return_format=return_format, json=plan._to_api_dict())
 
-        if return_format == "dict":
+        if return_format == "native":
             return Plan(**request)
 
         return request
 
     def edit(self, plan: Plan,
-             return_format: str = "dict") -> Union[Plan, bytes]:
+             return_format: str = "native") -> Union[Plan, bytes]:
         """Edits a flight plan linked to your account.
 
         Requires authentication.
@@ -101,15 +103,16 @@ class PlanAPI():
         plan : Plan
             The new Plan object to replace the old one associated with that ID
         return_format : str
-            The API response format, defaults to ``"dict"``
+            The API response format, defaults to ``"native"``.
+            Must be one of the keys in the table at the top of the page.
 
         Returns
         -------
         Union[Plan, bytes]
-            :class:`~flightplandb.datatypes.Plan` by default or if ``"dict"``
+            :class:`~flightplandb.datatypes.Plan` by default or if ``"native"``
             is specified as the ``return_format``.
 
-            ``bytes`` if a different format than ``"dict"`` was specified.
+            ``bytes`` if a different format than ``"native"`` was specified.
 
         Raises
         ------
@@ -123,7 +126,7 @@ class PlanAPI():
         plan_data = plan._to_api_dict()
         request = self._fp._patch(f"/plan/{plan_data['id']}", json=plan_data)
 
-        if return_format == "dict":
+        if return_format == "native":
             return Plan(**request)
 
         return request
@@ -258,7 +261,7 @@ class PlanAPI():
         return True
 
     def generate(self, gen_query: GenerateQuery,
-                 return_format: str = "dict") -> Union[Plan, bytes]:
+                 return_format: str = "native") -> Union[Plan, bytes]:
         """Creates a new flight plan using the route generator.
 
         Requires authentication.
@@ -268,15 +271,16 @@ class PlanAPI():
         gen_query : GenerateQuery
             A dataclass with options for flight plan generation
         return_format : str
-            The API response format, defaults to ``"dict"``
+            The API response format, defaults to ``"native"``.
+            Must be one of the keys in the table at the top of the page.
 
         Returns
         -------
         Union[Plan, bytes]
-            Plan by default or if ``"dict"`` is specified as
+            Plan by default or if ``"native"`` is specified as
             the ``return_format``.
 
-            Bytes if a different format than ``"dict"`` was specified
+            Bytes if a different format than ``"native"`` was specified
         """
 
         return Plan(
